@@ -7,13 +7,18 @@ import argparse
 import os
 import subprocess
 import traceback
-import urllib.request, urllib.error, urllib.parse
+import urllib.error, urllib.parse
 from . import utils
 import sys
 from shutil import copyfile
 from .agent import run_agent
 from time import sleep
 
+try:
+   from urllib.request import urlopen
+except ImportError:
+   from urllib2 import urlopen
+
 
 def main():
     s3_base_link = 'https://s3.amazonaws.com/spotinst-public/services/spotinst-agent'
@@ -247,8 +252,8 @@ def install_collector(collector_name, modules_path, s3_base_collectors_link):
 
 
 def get_worker_files(modules_path, s3_base_workers_link, worker_name):
-    py_response = urllib.request.urlopen(s3_base_workers_link + '/' + worker_name + '/' + worker_name + '.py')
-    yml_response = urllib.request.urlopen(s3_base_workers_link + '/' + worker_name + '/' + worker_name + '.yml')
+    py_response = urlopen(s3_base_workers_link + '/' + worker_name + '/' + worker_name + '.py')
+    yml_response = urlopen(s3_base_workers_link + '/' + worker_name + '/' + worker_name + '.yml')
 
     with open(modules_path + '/' + worker_name + '.py', 'wb') as worker:
         worker.write(py_response.read())
@@ -259,16 +264,16 @@ def get_worker_files(modules_path, s3_base_workers_link, worker_name):
 def get_collector_files(collector_name, modules_path, s3_base_collectors_link):
     with open(modules_path + '/' + collector_name + '.py', 'wb') as collector:
         print(s3_base_collectors_link + '/' + collector_name + '/' + collector_name + '.py')
-        response = urllib.request.urlopen(s3_base_collectors_link + '/' + collector_name + '/' + collector_name + '.py')
+        response = urlopen(s3_base_collectors_link + '/' + collector_name + '/' + collector_name + '.py')
         collector.write(response.read())
     with open(modules_path + '/' + collector_name + '.yml', 'wb') as collector_cfg:
-        response = urllib.request.urlopen(s3_base_collectors_link + '/' + collector_name + '/' + collector_name + '.yml')
+        response = urlopen(s3_base_collectors_link + '/' + collector_name + '/' + collector_name + '.yml')
         collector_cfg.write(response.read())
 
 
 def handle_prerequisites(s3_base_module_link, module_name):
     try:
-        response = urllib.request.urlopen(s3_base_module_link + '/' + module_name + '/' + module_name + '.req')
+        response = urlopen(s3_base_module_link + '/' + module_name + '/' + module_name + '.req')
         requirements_file = response.read().decode('utf-8')
         requirements_names = requirements_file.split("\n")
         print ("This module requires the following packages to be installed:")
